# Welcome to geohey

[![image](https://img.shields.io/pypi/v/geohey.svg)](https://pypi.python.org/pypi/geohey)

**A Python package demo for geospatial analysis**

-   Free software: MIT License
-   Documentation: <https://geohey.gishub.org>

## Features

-   Create interactive maps
-   Visualize geospatial data
-   Visualize raster data
-   Visualize vector data

## Demos

![](https://wetlands.io/file/images/youtube.png)
